@@ -19,7 +19,7 @@ import (
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 	randutil "k8s.io/apimachinery/pkg/util/rand"
 	"k8s.io/client-go/kubernetes"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	"k8s.io/utils/pointer"
 
 	configv1 "github.com/openshift/api/config/v1"
@@ -39,7 +39,7 @@ func (optr *Operator) defaultPayloadRetriever() PayloadRetriever {
 	return &payloadRetriever{
 		kubeClient:   optr.kubeClient,
 		operatorName: optr.name,
-		releaseImage: optr.releaseImage,
+		releaseImage: optr.release.Image,
 		namespace:    optr.namespace,
 		nodeName:     optr.nodename,
 		payloadDir:   optr.defaultPayloadDir(),
@@ -201,12 +201,12 @@ func (r *payloadRetriever) fetchUpdatePayloadToDir(ctx context.Context, dir stri
 	}
 
 	// Prune older jobs while gracefully handling errors.
-	err := r.pruneJobs(2)
+	err := r.pruneJobs(ctx, 2)
 	if err != nil {
 		klog.Warningf("failed to prune jobs: %v", err)
 	}
 
-	_, err = r.kubeClient.BatchV1().Jobs(job.Namespace).Create(job)
+	_, err = r.kubeClient.BatchV1().Jobs(job.Namespace).Create(ctx, job, metav1.CreateOptions{})
 	if err != nil {
 		return err
 	}
@@ -215,8 +215,8 @@ func (r *payloadRetriever) fetchUpdatePayloadToDir(ctx context.Context, dir stri
 
 // pruneJobs deletes the older, finished jobs in the namespace.
 // retain - the number of newest jobs to keep.
-func (r *payloadRetriever) pruneJobs(retain int) error {
-	jobs, err := r.kubeClient.BatchV1().Jobs(r.namespace).List(metav1.ListOptions{})
+func (r *payloadRetriever) pruneJobs(ctx context.Context, retain int) error {
+	jobs, err := r.kubeClient.BatchV1().Jobs(r.namespace).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
 	}
@@ -258,7 +258,7 @@ func (r *payloadRetriever) pruneJobs(retain int) error {
 
 	var errs []error
 	for _, job := range deleteJobs[:len(deleteJobs)-retain] {
-		err := r.kubeClient.BatchV1().Jobs(r.namespace).Delete(job.Name, &metav1.DeleteOptions{})
+		err := r.kubeClient.BatchV1().Jobs(r.namespace).Delete(ctx, job.Name, metav1.DeleteOptions{})
 		if err != nil {
 			errs = append(errs, errors.Wrapf(err, "failed to delete job %v", job.Name))
 		}
@@ -304,13 +304,21 @@ func findUpdateFromConfig(config *configv1.ClusterVersion) (configv1.Update, boo
 
 func findUpdateFromConfigVersion(config *configv1.ClusterVersion, version string, force bool) (configv1.Update, bool) {
 	for _, update := range config.Status.AvailableUpdates {
-		if update.Version == version {
-			return update, len(update.Image) > 0
+		if update.Version == version && len(update.Image) > 0 {
+			return configv1.Update{
+				Version: version,
+				Image:   update.Image,
+				Force:   force,
+			}, true
 		}
 	}
 	for _, history := range config.Status.History {
-		if history.Version == version {
-			return configv1.Update{Image: history.Image, Version: history.Version, Force: force}, len(history.Image) > 0
+		if history.Version == version && len(history.Image) > 0 {
+			return configv1.Update{
+				Version: version,
+				Image:   history.Image,
+				Force:   force,
+			}, true
 		}
 	}
 	return configv1.Update{}, false
